@@ -9,8 +9,8 @@ def print_info() -> None:
     Print package info to stdout.
     """
     print(
-        "Type annotations for boto3.Proton 1.26.11\nVersion:         1.26.11.post1\nBuilder"
-        " version: 7.11.10\nDocs:           "
+        "Type annotations for boto3.Proton 1.26.22\nVersion:         1.26.22\nBuilder version:"
+        " 7.11.11\nDocs:           "
         " https://youtype.github.io/boto3_stubs_docs/mypy_boto3_proton//\nBoto3 docs:     "
         " https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton\nOther"
         " services:  https://pypi.org/project/boto3-stubs/\nChangelog:      "
@@ -22,7 +22,7 @@ def print_version() -> None:
     """
     Print package version to stdout.
     """
-    print("1.26.11.post1")
+    print("1.26.22")
 
 
 def main() -> None:
