@@ -309,10 +309,10 @@ class ProtonClient(BaseClient):
         *,
         environmentName: str,
         managementAccountId: str,
-        roleArn: str,
         clientToken: str = ...,
         codebuildRoleArn: str = ...,
         componentRoleArn: str = ...,
+        roleArn: str = ...,
         tags: Sequence[TagTypeDef] = ...
     ) -> CreateEnvironmentAccountConnectionOutputTypeDef:
         """
