@@ -65,7 +65,9 @@ from botocore.paginate import PageIterator, Paginator
 from .literals import (
     EnvironmentAccountConnectionRequesterAccountTypeType,
     EnvironmentAccountConnectionStatusType,
+    ListServiceInstancesSortByType,
     RepositoryProviderType,
+    SortOrderType,
 )
 from .type_defs import (
     EnvironmentTemplateFilterTypeDef,
@@ -82,6 +84,7 @@ from .type_defs import (
     ListRepositorySyncDefinitionsOutputTypeDef,
     ListServiceInstanceOutputsOutputTypeDef,
     ListServiceInstanceProvisionedResourcesOutputTypeDef,
+    ListServiceInstancesFilterTypeDef,
     ListServiceInstancesOutputTypeDef,
     ListServicePipelineOutputsOutputTypeDef,
     ListServicePipelineProvisionedResourcesOutputTypeDef,
@@ -364,7 +367,13 @@ class ListServiceInstancesPaginator(Paginator):
     """
 
     def paginate(
-        self, *, serviceName: str = ..., PaginationConfig: PaginatorConfigTypeDef = ...
+        self,
+        *,
+        filters: Sequence[ListServiceInstancesFilterTypeDef] = ...,
+        serviceName: str = ...,
+        sortBy: ListServiceInstancesSortByType = ...,
+        sortOrder: SortOrderType = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[ListServiceInstancesOutputTypeDef]:
         """
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/proton.html#Proton.Paginator.ListServiceInstances.paginate)
